pub fn init_zsh(config: &Config) -> Result<String, LeadrError>Expand description
Generates a zsh script that handles the resulting command and binds it to the leadr key.
pub fn init_zsh(config: &Config) -> Result<String, LeadrError>Generates a zsh script that handles the resulting command and binds it to the leadr key.